==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/EaseOfMovementIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { EaseOfMovementIndicatorDescription } from "./EaseOfMovementIndicatorDescription";
/**
 * @hidden
 */
export let EaseOfMovementIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class EaseOfMovementIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (EaseOfMovementIndicatorDescriptionMetadata.a == null) {
                EaseOfMovementIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EaseOfMovementIndicatorDescriptionMetadata.c(EaseOfMovementIndicatorDescriptionMetadata.a);
            }
            if (a.k(EaseOfMovementIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(EaseOfMovementIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            EaseOfMovementIndicatorDescriptionMetadata.b(a);
            a.ad("EaseOfMovementIndicator", () => new EaseOfMovementIndicatorDescription());
            a.ac("EaseOfMovementIndicator", EaseOfMovementIndicatorDescriptionMetadata.a);
        }
    }
    EaseOfMovementIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(EaseOfMovementIndicatorDescriptionMetadata, 'EaseOfMovementIndicatorDescriptionMetadata');
    EaseOfMovementIndicatorDescriptionMetadata.a = null;
    return EaseOfMovementIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/EaseOfMovementIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { EaseOfMovementIndicatorDescription } from "./EaseOfMovementIndicatorDescription";
/**
 * @hidden
 */
export let EaseOfMovementIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class EaseOfMovementIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (EaseOfMovementIndicatorDescriptionMetadata.a == null) {
                EaseOfMovementIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EaseOfMovementIndicatorDescriptionMetadata.c(EaseOfMovementIndicatorDescriptionMetadata.a);
            }
            if (a.k(EaseOfMovementIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(EaseOfMovementIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            EaseOfMovementIndicatorDescriptionMetadata.b(a);
            a.ae("EaseOfMovementIndicator", () => new EaseOfMovementIndicatorDescription());
            a.ad("EaseOfMovementIndicator", EaseOfMovementIndicatorDescriptionMetadata.a);
        }
    }
    EaseOfMovementIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(EaseOfMovementIndicatorDescriptionMetadata, 'EaseOfMovementIndicatorDescriptionMetadata');
    EaseOfMovementIndicatorDescriptionMetadata.a = null;
    return EaseOfMovementIndicatorDescriptionMetadata;
})();
